@@ -3,13 +3,15 @@ Main interface for dlm service client
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.dlm import DLMClient
+    from mypy_boto3_dlm import DLMClient
 
     session = boto3.Session()
 
     client: DLMClient = boto3.client("dlm")
     session_client: DLMClient = session.client("dlm")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
@@ -42,14 +44,14 @@ class Exceptions:
 
 class DLMClient:
     """
-    [DLM.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.15/reference/services/dlm.html#DLM.Client)
+    [DLM.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/dlm.html#DLM.Client)
     """
 
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.15/reference/services/dlm.html#DLM.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/dlm.html#DLM.Client.can_paginate)
         """
 
     def create_lifecycle_policy(
@@ -57,16 +59,16 @@ class DLMClient:
         ExecutionRoleArn: str,
         Description: str,
         State: Literal["ENABLED", "DISABLED"],
-        PolicyDetails: PolicyDetailsTypeDef,
+        PolicyDetails: "PolicyDetailsTypeDef",
         Tags: Dict[str, str] = None,
     ) -> CreateLifecyclePolicyResponseTypeDef:
         """
-        [Client.create_lifecycle_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.15/reference/services/dlm.html#DLM.Client.create_lifecycle_policy)
+        [Client.create_lifecycle_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/dlm.html#DLM.Client.create_lifecycle_policy)
         """
 
     def delete_lifecycle_policy(self, PolicyId: str) -> Dict[str, Any]:
         """
-        [Client.delete_lifecycle_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.15/reference/services/dlm.html#DLM.Client.delete_lifecycle_policy)
+        [Client.delete_lifecycle_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/dlm.html#DLM.Client.delete_lifecycle_policy)
         """
 
     def generate_presigned_url(
@@ -77,7 +79,7 @@ class DLMClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.15/reference/services/dlm.html#DLM.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/dlm.html#DLM.Client.generate_presigned_url)
         """
 
     def get_lifecycle_policies(
@@ -89,27 +91,27 @@ class DLMClient:
         TagsToAdd: List[str] = None,
     ) -> GetLifecyclePoliciesResponseTypeDef:
         """
-        [Client.get_lifecycle_policies documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.15/reference/services/dlm.html#DLM.Client.get_lifecycle_policies)
+        [Client.get_lifecycle_policies documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/dlm.html#DLM.Client.get_lifecycle_policies)
         """
 
     def get_lifecycle_policy(self, PolicyId: str) -> GetLifecyclePolicyResponseTypeDef:
         """
-        [Client.get_lifecycle_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.15/reference/services/dlm.html#DLM.Client.get_lifecycle_policy)
+        [Client.get_lifecycle_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/dlm.html#DLM.Client.get_lifecycle_policy)
         """
 
     def list_tags_for_resource(self, ResourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.15/reference/services/dlm.html#DLM.Client.list_tags_for_resource)
+        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/dlm.html#DLM.Client.list_tags_for_resource)
         """
 
     def tag_resource(self, ResourceArn: str, Tags: Dict[str, str]) -> Dict[str, Any]:
         """
-        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.15/reference/services/dlm.html#DLM.Client.tag_resource)
+        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/dlm.html#DLM.Client.tag_resource)
         """
 
     def untag_resource(self, ResourceArn: str, TagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.15/reference/services/dlm.html#DLM.Client.untag_resource)
+        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/dlm.html#DLM.Client.untag_resource)
         """
 
     def update_lifecycle_policy(
@@ -118,8 +120,8 @@ class DLMClient:
         ExecutionRoleArn: str = None,
         State: Literal["ENABLED", "DISABLED"] = None,
         Description: str = None,
-        PolicyDetails: PolicyDetailsTypeDef = None,
+        PolicyDetails: "PolicyDetailsTypeDef" = None,
     ) -> Dict[str, Any]:
         """
-        [Client.update_lifecycle_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.15/reference/services/dlm.html#DLM.Client.update_lifecycle_policy)
+        [Client.update_lifecycle_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/dlm.html#DLM.Client.update_lifecycle_policy)
         """
