@@ -3,9 +3,11 @@ Main interface for dlm service type definitions.
 
 Usage::
 
-    from mypy_boto3.dlm.type_defs import CreateLifecyclePolicyResponseTypeDef
+    ```python
+    from mypy_boto3_dlm.type_defs import CreateRuleTypeDef
 
-    data: CreateLifecyclePolicyResponseTypeDef = {...}
+    data: CreateRuleTypeDef = {...}
+    ```
 """
 from datetime import datetime
 import sys
@@ -22,58 +24,29 @@ else:
 
 
 __all__ = (
-    "CreateLifecyclePolicyResponseTypeDef",
-    "LifecyclePolicySummaryTypeDef",
-    "GetLifecyclePoliciesResponseTypeDef",
-    "ParametersTypeDef",
     "CreateRuleTypeDef",
     "CrossRegionCopyRetainRuleTypeDef",
     "CrossRegionCopyRuleTypeDef",
     "FastRestoreRuleTypeDef",
-    "RetainRuleTypeDef",
-    "TagTypeDef",
-    "ScheduleTypeDef",
-    "PolicyDetailsTypeDef",
+    "LifecyclePolicySummaryTypeDef",
     "LifecyclePolicyTypeDef",
+    "ParametersTypeDef",
+    "PolicyDetailsTypeDef",
+    "RetainRuleTypeDef",
+    "ScheduleTypeDef",
+    "TagTypeDef",
+    "CreateLifecyclePolicyResponseTypeDef",
+    "GetLifecyclePoliciesResponseTypeDef",
     "GetLifecyclePolicyResponseTypeDef",
     "ListTagsForResourceResponseTypeDef",
 )
 
-CreateLifecyclePolicyResponseTypeDef = TypedDict(
-    "CreateLifecyclePolicyResponseTypeDef", {"PolicyId": str}, total=False
-)
-
-LifecyclePolicySummaryTypeDef = TypedDict(
-    "LifecyclePolicySummaryTypeDef",
-    {
-        "PolicyId": str,
-        "Description": str,
-        "State": Literal["ENABLED", "DISABLED", "ERROR"],
-        "Tags": Dict[str, str],
-    },
+CreateRuleTypeDef = TypedDict(
+    "CreateRuleTypeDef",
+    {"Interval": int, "IntervalUnit": Literal["HOURS"], "Times": List[str], "CronExpression": str},
     total=False,
 )
 
-GetLifecyclePoliciesResponseTypeDef = TypedDict(
-    "GetLifecyclePoliciesResponseTypeDef",
-    {"Policies": List[LifecyclePolicySummaryTypeDef]},
-    total=False,
-)
-
-ParametersTypeDef = TypedDict("ParametersTypeDef", {"ExcludeBootVolume": bool}, total=False)
-
-_RequiredCreateRuleTypeDef = TypedDict(
-    "_RequiredCreateRuleTypeDef", {"Interval": int, "IntervalUnit": Literal["HOURS"]}
-)
-_OptionalCreateRuleTypeDef = TypedDict(
-    "_OptionalCreateRuleTypeDef", {"Times": List[str]}, total=False
-)
-
-
-class CreateRuleTypeDef(_RequiredCreateRuleTypeDef, _OptionalCreateRuleTypeDef):
-    pass
-
-
 CrossRegionCopyRetainRuleTypeDef = TypedDict(
     "CrossRegionCopyRetainRuleTypeDef",
     {"Interval": int, "IntervalUnit": Literal["DAYS", "WEEKS", "MONTHS", "YEARS"]},
@@ -85,7 +58,7 @@ _RequiredCrossRegionCopyRuleTypeDef = TypedDict(
 )
 _OptionalCrossRegionCopyRuleTypeDef = TypedDict(
     "_OptionalCrossRegionCopyRuleTypeDef",
-    {"CmkArn": str, "CopyTags": bool, "RetainRule": CrossRegionCopyRetainRuleTypeDef},
+    {"CmkArn": str, "CopyTags": bool, "RetainRule": "CrossRegionCopyRetainRuleTypeDef"},
     total=False,
 )
 
@@ -110,37 +83,13 @@ class FastRestoreRuleTypeDef(_RequiredFastRestoreRuleTypeDef, _OptionalFastResto
     pass
 
 
-RetainRuleTypeDef = TypedDict(
-    "RetainRuleTypeDef",
-    {"Count": int, "Interval": int, "IntervalUnit": Literal["DAYS", "WEEKS", "MONTHS", "YEARS"]},
-    total=False,
-)
-
-TagTypeDef = TypedDict("TagTypeDef", {"Key": str, "Value": str})
-
-ScheduleTypeDef = TypedDict(
-    "ScheduleTypeDef",
+LifecyclePolicySummaryTypeDef = TypedDict(
+    "LifecyclePolicySummaryTypeDef",
     {
-        "Name": str,
-        "CopyTags": bool,
-        "TagsToAdd": List[TagTypeDef],
-        "VariableTags": List[TagTypeDef],
-        "CreateRule": CreateRuleTypeDef,
-        "RetainRule": RetainRuleTypeDef,
-        "FastRestoreRule": FastRestoreRuleTypeDef,
-        "CrossRegionCopyRules": List[CrossRegionCopyRuleTypeDef],
-    },
-    total=False,
-)
-
-PolicyDetailsTypeDef = TypedDict(
-    "PolicyDetailsTypeDef",
-    {
-        "PolicyType": Literal["EBS_SNAPSHOT_MANAGEMENT"],
-        "ResourceTypes": List[Literal["VOLUME", "INSTANCE"]],
-        "TargetTags": List[TagTypeDef],
-        "Schedules": List[ScheduleTypeDef],
-        "Parameters": ParametersTypeDef,
+        "PolicyId": str,
+        "Description": str,
+        "State": Literal["ENABLED", "DISABLED", "ERROR"],
+        "Tags": Dict[str, str],
     },
     total=False,
 )
@@ -155,15 +104,62 @@ LifecyclePolicyTypeDef = TypedDict(
         "ExecutionRoleArn": str,
         "DateCreated": datetime,
         "DateModified": datetime,
-        "PolicyDetails": PolicyDetailsTypeDef,
+        "PolicyDetails": "PolicyDetailsTypeDef",
         "Tags": Dict[str, str],
         "PolicyArn": str,
     },
     total=False,
 )
 
+ParametersTypeDef = TypedDict("ParametersTypeDef", {"ExcludeBootVolume": bool}, total=False)
+
+PolicyDetailsTypeDef = TypedDict(
+    "PolicyDetailsTypeDef",
+    {
+        "PolicyType": Literal["EBS_SNAPSHOT_MANAGEMENT"],
+        "ResourceTypes": List[Literal["VOLUME", "INSTANCE"]],
+        "TargetTags": List["TagTypeDef"],
+        "Schedules": List["ScheduleTypeDef"],
+        "Parameters": "ParametersTypeDef",
+    },
+    total=False,
+)
+
+RetainRuleTypeDef = TypedDict(
+    "RetainRuleTypeDef",
+    {"Count": int, "Interval": int, "IntervalUnit": Literal["DAYS", "WEEKS", "MONTHS", "YEARS"]},
+    total=False,
+)
+
+ScheduleTypeDef = TypedDict(
+    "ScheduleTypeDef",
+    {
+        "Name": str,
+        "CopyTags": bool,
+        "TagsToAdd": List["TagTypeDef"],
+        "VariableTags": List["TagTypeDef"],
+        "CreateRule": "CreateRuleTypeDef",
+        "RetainRule": "RetainRuleTypeDef",
+        "FastRestoreRule": "FastRestoreRuleTypeDef",
+        "CrossRegionCopyRules": List["CrossRegionCopyRuleTypeDef"],
+    },
+    total=False,
+)
+
+TagTypeDef = TypedDict("TagTypeDef", {"Key": str, "Value": str})
+
+CreateLifecyclePolicyResponseTypeDef = TypedDict(
+    "CreateLifecyclePolicyResponseTypeDef", {"PolicyId": str}, total=False
+)
+
+GetLifecyclePoliciesResponseTypeDef = TypedDict(
+    "GetLifecyclePoliciesResponseTypeDef",
+    {"Policies": List["LifecyclePolicySummaryTypeDef"]},
+    total=False,
+)
+
 GetLifecyclePolicyResponseTypeDef = TypedDict(
-    "GetLifecyclePolicyResponseTypeDef", {"Policy": LifecyclePolicyTypeDef}, total=False
+    "GetLifecyclePolicyResponseTypeDef", {"Policy": "LifecyclePolicyTypeDef"}, total=False
 )
 
 ListTagsForResourceResponseTypeDef = TypedDict(
